/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.validator;

import woolpack.utils.Switchable;

/**
 * 文字列と{@link ValidatorExpression}の{@link Switchable}をプロパティとして持つ{@link ValidatorExpression}。
 * 適用しているパターン：フィルタ。
 * @author nakamura
 *
 */
abstract public class BranchValidator implements ValidatorExpression {
	private final Switchable<String,ValidatorExpression> switchable;
	
	/**
	 * コンストラクタ。
	 * @param switchable 文字列と{@link ValidatorExpression}の{@link Switchable}。
	 * @throws NullPointerException 引数が null の場合。
	 */
	public BranchValidator(final Switchable<String,ValidatorExpression> switchable){
		switchable.getClass();
		this.switchable = switchable;
	}

	/**
	 * サブクラスで実装する。
	 */
	abstract public boolean interpret(final ValidatorContext context);
	
	/**
	 * 文字列と{@link ValidatorExpression}の{@link Switchable}を返す。
	 * @return 文字列と{@link ValidatorExpression}の{@link Switchable}。
	 */
	public Switchable<String,ValidatorExpression> getSwitchable(){
		return switchable;
	}
}
