/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.text;

import java.text.DecimalFormat;
import java.text.Format;
import java.text.ParseException;

import junit.framework.TestCase;

public class ToIntegerFormatTest extends TestCase {

	public void testConstructor(){
		try{
			new ToIntegerFormat(null);
			fail();
		}catch(final NullPointerException e){
		}
	}
	
	private void scenario(final Format format) throws ParseException{
		assertEquals("1", format.format(new Integer(1)));
		assertEquals(new Integer(1), format.parseObject("1"));
		assertEquals(new Integer(Integer.MAX_VALUE), format.parseObject(String.valueOf(Integer.MAX_VALUE)));
		assertEquals(new Integer(Integer.MIN_VALUE), format.parseObject(String.valueOf(Integer.MIN_VALUE)));
		
		try{
			format.parseObject("1.5");
			fail();
		}catch(final ParseException e){
		}
		
		try{
			format.parseObject(String.valueOf(((long)Integer.MAX_VALUE) + 1));
			fail();
		}catch(final ParseException e){
		}
		
		try{
			format.parseObject(String.valueOf(((long)Integer.MIN_VALUE) - 1));
			fail();
		}catch(final ParseException e){
		}
		
		try{
			format.parseObject("a");
			fail();
		}catch(final ParseException e){
		}
	}

	public void testNormal() throws ParseException{
		final Format format0 = new ToIntegerFormat();
		scenario(format0);
		final Format format1 = (Format)format0.clone();
		assertTrue(format0 != format1);
		scenario(format1);
	}

	public void testNormal2() throws ParseException{
		final Format format0 = new ToIntegerFormat(new DecimalFormat());
		scenario(format0);
		final Format format1 = (Format)format0.clone();
		assertTrue(format0 != format1);
		scenario(format1);
	}
}
