/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.validator;

import junit.framework.TestCase;
import woolpack.utils.SwitchBuilder;

public class BranchByIdValidatorTest extends TestCase {

	public void testConstructor(){
		try{
			new BranchByIdValidator(null);
			fail();
		}catch(final NullPointerException expected){
		}
	}

	public void testNotMatch(){
		final CountValidator counter0 = new CountValidator(ValidatorConstants.FALSE);
		final CountValidator counter1 = new CountValidator(ValidatorConstants.TRUE);
		final ValidatorExpression expression = new BranchByIdValidator(
				new SwitchBuilder<String,ValidatorExpression>()
				.put("a", counter0)
				.put("b", counter1)
				.get());
		final ValidatorContext context = new ValidatorContext();
		context.setId("z");
		assertTrue(expression.interpret(context));
		assertEquals(0, counter0.getCount());
		assertEquals(0, counter1.getCount());
	}

	public void testMatchFalse(){
		final CountValidator counter0 = new CountValidator(ValidatorConstants.FALSE);
		final CountValidator counter1 = new CountValidator(ValidatorConstants.TRUE);
		final ValidatorExpression expression = new BranchByIdValidator(
				new SwitchBuilder<String,ValidatorExpression>()
				.put("a", counter0)
				.put("b", counter1)
				.get());
		final ValidatorContext context = new ValidatorContext();
		context.setId("a");
		assertFalse(expression.interpret(context));
		assertEquals(1, counter0.getCount());
		assertEquals(0, counter1.getCount());
		assertTrue(context == counter0.getContextList().getLast());
	}

	public void testMatchTrue(){
		final CountValidator counter0 = new CountValidator(ValidatorConstants.FALSE);
		final CountValidator counter1 = new CountValidator(ValidatorConstants.TRUE);
		final ValidatorExpression expression = new BranchByIdValidator(
				new SwitchBuilder<String,ValidatorExpression>()
				.put("a", counter0)
				.put("b", counter1)
				.get());
		final ValidatorContext context = new ValidatorContext();
		context.setId("b");
		assertTrue(expression.interpret(context));
		assertEquals(0, counter0.getCount());
		assertEquals(1, counter1.getCount());
		assertTrue(context == counter1.getContextList().getLast());
	}
}
